.. _diffyg:

===============
Diffy G Methods
===============

Indirect method of optimization based on differential geometry.

Controls are handled in one of two ways. ICRM [1]_ or PMP.

Path constraints aren't handled... for now...

Base Class Reference
--------------------

.. module:: beluga.optimlib.diffyg

.. autofunction:: ocp_to_bvp

References
----------

.. [1] Michael J. Sparapany, and Michael J. Grant. "The Geometric Adjoining of Optimal Information in Indirect Trajectory Optimization." 2018 AIAA Guidance, Navigation, and Control Conference. 2018.
